@@ -9,7 +9,7 @@ require Exporter;
 @ISA = qw(Exporter);
 @EXPORT_OK = qw(info);
 
-use 5.010000;
+use v5.10.1;
 
 sub info {
     system('perldoc', __PACKAGE__);
@@ -25,7 +25,7 @@ PerlMongers::Hannover - Hannover Perl Mongers
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =head1 SYNOPSIS
 
@@ -51,7 +51,7 @@ L<mailto:hannover-pm@pm.org>
 
 =head2 Meetups
 
-Every even calendar week Tuesday at 6pm; date and location details announced
+Every odd calendar week Tuesday at 6pm; date and location details announced
 via Twitter, email and via the web site:
 
 http://hannover.pm/treffen
